KeyResponseMessage

Struct KeyResponseMessage 

pub struct KeyResponseMessage {
    pub result: bool,
    pub message: SmolStr,
    pub keys: SecretKeys,
    pub primary_key: Option<SecretKey>,
}
Available on crate feature encryption only.
Key response message

Fields

result: bool

Indicates true/false if there were errors or not

message: SmolStr

Contains error messages or other information

keys: SecretKeys

Used in listing queries to relay a list of installed keys

primary_key: Option<SecretKey>

Used in listing queries to relay the primary key

Implementations

Source

impl KeyResponseMessage

pub const fn result(&self) -> &bool

Returns true/false if there were errors or not

pub const fn message(&self) -> &SmolStr

Returns the error messages or other information

pub const fn keys(&self) -> &SecretKeys

Returns a list of installed keys

pub const fn primary_key(&self) -> &Option<SecretKey>

Returns the primary key

pub const fn with_result(self, val: bool) -> Self

Sets true/false if there were errors or not (Builder pattern)

pub fn with_message(self, val: SmolStr) -> Self

Sets the error messages or other information (Builder pattern)

pub fn with_keys(self, val: SecretKeys) -> Self

Sets the the list of installed keys (Builder pattern)

pub fn with_primary_key(self, val: Option<SecretKey>) -> Self

Sets the primary key (Builder pattern)

Source

impl KeyResponseMessage

pub fn add_key(&mut self, key: SecretKey) -> &mut Self

Adds a key to the list of keys