pub trait AsMessageRef<I, A> {
// Required method
fn as_message_ref(&self) -> SerfMessageRef<'_, I, A>;
}Expand description
Used to do a cheap reference to message reference conversion.
Required Methods
Sourcefn as_message_ref(&self) -> SerfMessageRef<'_, I, A>
fn as_message_ref(&self) -> SerfMessageRef<'_, I, A>
Converts this type into a shared reference of the (usually inferred) input type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<I, A> AsMessageRef<I, A> for &Arc<Member<I, A>>
impl<I, A> AsMessageRef<I, A> for &Arc<Member<I, A>>
fn as_message_ref(&self) -> SerfMessageRef<'_, I, A>
Implementors
impl<I, A> AsMessageRef<I, A> for &SerfMessage<I, A>
impl<I, A> AsMessageRef<I, A> for &JoinMessage<I>
impl<I, A> AsMessageRef<I, A> for &KeyRequestMessage
Available on crate feature
encryption only.impl<I, A> AsMessageRef<I, A> for &KeyResponseMessage
Available on crate feature
encryption only.